==> visualvm_1.3.9.orig.tar.xz: visualvm-1.3.9/netbeans/profiler.api/src/org/netbeans/modules/profiler/api/icons/LanguageIcons.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2011 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2011 Sun Microsystems, Inc.
 */
package org.netbeans.modules.profiler.api.icons;

/**
 *
 * @author Jiri Sedlacek
 */
public interface LanguageIcons extends Icons.Keys {
    
    public static final String CLASS = "LanguageIcons.Class"; // NOI18N
    public static final String CONSTRUCTOR_PACKAGE = "LanguageIcons.ConstructorPackage"; // NOI18N
    public static final String CONSTRUCTOR_PRIVATE = "LanguageIcons.ConstructorPrivate"; // NOI18N
    public static final String CONSTRUCTOR_PROTECTED = "LanguageIcons.ConstructorProtected"; // NOI18N
    public static final String CONSTRUCTOR_PUBLIC = "LanguageIcons.ConstructorPublic"; // NOI18N
    public static final String CONSTRUCTORS = "LanguageIcons.Constructors"; // NOI18N
    public static final String INITIALIZER = "LanguageIcons.Initializer"; // NOI18N
    public static final String INITIALIZER_STATIC = "LanguageIcons.InitializerStatic"; // NOI18N
    public static final String INTERFACE = "LanguageIcons.Interface"; // NOI18N
    public static final String LIBRARIES = "LanguageIcons.Libraries"; // NOI18N
    public static final String METHOD_PACKAGE = "LanguageIcons.MethodPackage"; // NOI18N
    public static final String METHOD_PRIVATE = "LanguageIcons.MethodPrivate"; // NOI18N
    public static final String METHOD_PROTECTED = "LanguageIcons.MethodProtected"; // NOI18N
    public static final String METHOD_PUBLIC = "LanguageIcons.MethodPublic"; // NOI18N
    public static final String METHOD_PACKAGE_STATIC = "LanguageIcons.MethodPackageStatic"; // NOI18N
    public static final String METHOD_PRIVATE_STATIC = "LanguageIcons.MethodPrivateStatic"; // NOI18N
    public static final String METHOD_PROTECTED_STATIC = "LanguageIcons.MethodProtectedStatic"; // NOI18N
    public static final String METHOD_PUBLIC_STATIC = "LanguageIcons.MethodPublicStatic"; // NOI18N
    public static final String METHODS = "LanguageIcons.Methods"; // NOI18N
    public static final String PACKAGE = "LanguageIcons.Package"; // NOI18N
    public static final String VARIABLE_PACKAGE = "LanguageIcons.VariablePackage"; // NOI18N
    public static final String VARIABLE_PRIVATE = "LanguageIcons.VariablePrivate"; // NOI18N
    public static final String VARIABLE_PROTECTED = "LanguageIcons.VariableProtected"; // NOI18N
    public static final String VARIABLE_PUBLIC = "LanguageIcons.VariablePublic"; // NOI18N
    public static final String VARIABLE_PACKAGE_STATIC = "LanguageIcons.VariablePackageStatic"; // NOI18N
    public static final String VARIABLE_PRIVATE_STATIC = "LanguageIcons.VariablePrivateStatic"; // NOI18N
    public static final String VARIABLE_PROTECTED_STATIC = "LanguageIcons.VariableProtectedStatic"; // NOI18N
    public static final String VARIABLE_PUBLIC_STATIC = "LanguageIcons.VariablePublicStatic"; // NOI18N
    public static final String VARIABLES = "LanguageIcons.Variables"; // NOI18N
    public static final String ARRAY = "LanguageIcons.Array"; // NOI18N
    public static final String INSTANCE = "LanguageIcons.Instance"; // NOI18N
    public static final String PRIMITIVE = "LanguageIcons.Primitive"; // NOI18N
    public static final String JAR = "LanguangeIcons.Jar"; // NOI18N
}

==> visualvm_1.4.2.orig.tar.xz: visualvm-1.4.2/netbeans/profiler.api/src/org/netbeans/modules/profiler/api/icons/LanguageIcons.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2011 Oracle and/or its affiliates. All rights reserved.
 *
 * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
 * Other names may be trademarks of their respective owners.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common
 * Development and Distribution License("CDDL") (collectively, the
 * "License"). You may not use this file except in compliance with the
 * License. You can obtain a copy of the License at
 * http://www.netbeans.org/cddl-gplv2.html
 * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
 * specific language governing permissions and limitations under the
 * License.  When distributing the software, include this License Header
 * Notice in each file and include the License file at
 * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the GPL Version 2 section of the License file that
 * accompanied this code. If applicable, add the following below the
 * License Header, with the fields enclosed by brackets [] replaced by
 * your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * If you wish your version of this file to be governed by only the CDDL
 * or only the GPL Version 2, indicate your decision by adding
 * "[Contributor] elects to include this software in this distribution
 * under the [CDDL or GPL Version 2] license." If you do not indicate a
 * single choice of license, a recipient has the option to distribute
 * your version of this file under either the CDDL, the GPL Version 2 or
 * to extend the choice of license to its licensees as provided above.
 * However, if you add GPL Version 2 code and therefore, elected the GPL
 * Version 2 license, then the option applies only if the new code is
 * made subject to such option by the copyright holder.
 *
 * Contributor(s):
 *
 * Portions Copyrighted 2011 Sun Microsystems, Inc.
 */
package org.netbeans.modules.profiler.api.icons;

/**
 *
 * @author Jiri Sedlacek
 */
public interface LanguageIcons extends Icons.Keys {
    
    public static final String CLASS = "LanguageIcons.Class"; // NOI18N
    public static final String CLASS_ANONYMOUS = "LanguageIcons.ClassAnonymous"; // NOI18N
    public static final String CONSTRUCTOR_PACKAGE = "LanguageIcons.ConstructorPackage"; // NOI18N
    public static final String CONSTRUCTOR_PRIVATE = "LanguageIcons.ConstructorPrivate"; // NOI18N
    public static final String CONSTRUCTOR_PROTECTED = "LanguageIcons.ConstructorProtected"; // NOI18N
    public static final String CONSTRUCTOR_PUBLIC = "LanguageIcons.ConstructorPublic"; // NOI18N
    public static final String CONSTRUCTORS = "LanguageIcons.Constructors"; // NOI18N
    public static final String INITIALIZER = "LanguageIcons.Initializer"; // NOI18N
    public static final String INITIALIZER_STATIC = "LanguageIcons.InitializerStatic"; // NOI18N
    public static final String INTERFACE = "LanguageIcons.Interface"; // NOI18N
    public static final String LIBRARIES = "LanguageIcons.Libraries"; // NOI18N
    public static final String METHOD_PACKAGE = "LanguageIcons.MethodPackage"; // NOI18N
    public static final String METHOD_PRIVATE = "LanguageIcons.MethodPrivate"; // NOI18N
    public static final String METHOD_PROTECTED = "LanguageIcons.MethodProtected"; // NOI18N
    public static final String METHOD_PUBLIC = "LanguageIcons.MethodPublic"; // NOI18N
    public static final String METHOD_PACKAGE_STATIC = "LanguageIcons.MethodPackageStatic"; // NOI18N
    public static final String METHOD_PRIVATE_STATIC = "LanguageIcons.MethodPrivateStatic"; // NOI18N
    public static final String METHOD_PROTECTED_STATIC = "LanguageIcons.MethodProtectedStatic"; // NOI18N
    public static final String METHOD_PUBLIC_STATIC = "LanguageIcons.MethodPublicStatic"; // NOI18N
    public static final String METHOD_INHERITED = "LanguageIcons.MethodInheritedStatic"; // NOI18N
    public static final String METHODS = "LanguageIcons.Methods"; // NOI18N
    public static final String METHOD = "LanguageIcons.Method"; // NOI18N
    public static final String PACKAGE = "LanguageIcons.Package"; // NOI18N
    public static final String VARIABLE_PACKAGE = "LanguageIcons.VariablePackage"; // NOI18N
    public static final String VARIABLE_PRIVATE = "LanguageIcons.VariablePrivate"; // NOI18N
    public static final String VARIABLE_PROTECTED = "LanguageIcons.VariableProtected"; // NOI18N
    public static final String VARIABLE_PUBLIC = "LanguageIcons.VariablePublic"; // NOI18N
    public static final String VARIABLE_PACKAGE_STATIC = "LanguageIcons.VariablePackageStatic"; // NOI18N
    public static final String VARIABLE_PRIVATE_STATIC = "LanguageIcons.VariablePrivateStatic"; // NOI18N
    public static final String VARIABLE_PROTECTED_STATIC = "LanguageIcons.VariableProtectedStatic"; // NOI18N
    public static final String VARIABLE_PUBLIC_STATIC = "LanguageIcons.VariablePublicStatic"; // NOI18N
    public static final String VARIABLES = "LanguageIcons.Variables"; // NOI18N
    public static final String ARRAY = "LanguageIcons.Array"; // NOI18N
    public static final String INSTANCE = "LanguageIcons.Instance"; // NOI18N
    public static final String PRIMITIVE = "LanguageIcons.Primitive"; // NOI18N
    public static final String JAR = "LanguangeIcons.Jar"; // NOI18N
}
